package squircle;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.datatransfer.Clipboard;
import java.awt.datatransfer.ClipboardOwner;
import java.awt.datatransfer.Transferable;
import java.awt.event.MouseWheelEvent;
import java.awt.event.MouseWheelListener;
import java.io.File;
import org.qenherkhopeshef.graphics.vectorClipboard.PictureFormat;
import org.qenherkhopeshef.graphics.vectorClipboard.SimpleClipGraphics;

import com.google.common.eventbus.EventBus;

import event.squircleevt.*;
import event.zoompan.ZoomEvent;


import processing.core.*;

public class SquircleApp extends PApplet implements ClipboardOwner, MouseWheelListener {
    
    private Squircle           s;
    private boolean            record;
    private RulerView          ruler;
    private ZoomPan            zp;
    private EventBus           eventBus;
    
    public void setup() {
        
        size(400, 400);
        
        
        eventBus = Ebus.get();
        
//        new File("c:/tenp/muell.pdf");
        zp = new ZoomPan(1);
        zp.moveX=200;
        zp.moveY=200;
//        eventBus.register(zp);
        ruler = new RulerView(this, zp);
        
        EventHeight eh = new EventHeight(150);
        EventWidth ew = new EventWidth(150);
        EventRadius er = new EventRadius(50);
        EventSquirc es = new EventSquirc(20);
        
        // Squircle braucht die DataObjects der events
        s = new Squircle(ew, eh, er, es);
        eventBus.register(s);
        
        ew.setPosition(s.w);
        eh.setPosition(s.h);
        er.setPosition(s.c1.start);
        es.setPosition(s.c1.pt2);
        
        // die Slider brauchen die events
        ruler.initSlider(ew, eh, er, es);
        
        frameRate(10);
        smooth();
        
        addMouseWheelListener(this);
    }
    
    public void draw() {
        background(255);
        zp.updateMousePosition(this);
        
        // stroke(150);
        
        pushMatrix();
        
        translate(zp.moveX, zp.moveY);
        
        scale(zp.zoom, zp.zoom);
        // Ab hier Zoom, Pan
        
        
        SimpleClipGraphics clipGraphics = null;
        Graphics2D cg = null;
        
        
        
        if (record) {
            
            clipGraphics = new SimpleClipGraphics(width, height);
            clipGraphics.setPictureFormat(PictureFormat.DIRECT_EMF);
            cg = clipGraphics.getGraphics();
            cg.setColor(Color.RED);
            cg.setStroke(null);
            
        }
        fill(Color.red.getRGB());
        
        noStroke();
        
        s.set();
        s.draw(this, cg, record);
        
        if (record) {
            
            record = false;
            cg.dispose();
            clipGraphics.copyToClipboard(this);
            
        }
        
        ruler.sliderDraw();
        
        popMatrix();
        
        ruler.mDraw();
    }
    
    static public void main(String args[]) {
        PApplet.main(new String[] { "--bgcolor=#E2E2E2",
                "squircle.SquircleApp" });
    }
    
    @Override
    public void lostOwnership(Clipboard clipboard, Transferable contents) {
        // TODO Auto-generated method stub
        
    }
    public void keyPressed(){
    	if (key=='c') {
			record=true;
		}
    }

	@Override
	public void mouseWheelMoved(MouseWheelEvent e) {

		if (e.getWheelRotation() < 0) {
			zp.targetZoomIn(pmouseX, pmouseY);
		} else {
			zp.targetZoomOut(pmouseX, pmouseY);
		}

		redraw();
	}

	public void mouseDragged() {
		// System.out.println(e.getButton());
		if (mouseButton == 39) {

			zp.pan(this);

		}

		redraw();
	}

	public void mouseMoved() {

		zp.updateMousePosition(this);

		if (!focused)
			requestFocusInWindow();
	}
}
